var fs = require('fs');

/**
 * from() : from(files, fn)
 * Reads from files. If no files are given, read from stdin.
 */

exports.from = function (files, fn) {
  var err;
  var out = {};

  if (!files || files.length === 0) {
    exports.stdin(function (err, data) {
      if (err) throw err;
      out['-'] = data;
      fn(err, out);
    });
  } else {
    files.forEach(function (fname) {
      out[fname] = fs.readFileSync(fname, 'utf-8');
    });
    fn(err, out);
  }
};

/**
 * stdin() : stdin(fn)
 * Read data from standard input.
 *
 *   stdin(function (err, data) {
 *     console.log(data);
 *   });
 */

exports.stdin = function (fn) {
  var data = '';

  process.stdin.setEncoding('utf8');
  process.stdin.on('readable', function() {
    var chunk = process.stdin.read();
    if (chunk !== null) data += chunk;
  });

  process.stdin.on('end', function() {
    fn(null, data);
  });
};
